@@ -57,17 +57,17 @@ sub linefit {
 	# leave this line as is
 	my ($x,$par,$ym,$dyda) = @_;
 
-	# $m and $b are fit parameters, internal to this function
+	# $m and $c are fit parameters, internal to this function
 	# call them whatever make sense to you, but replace (0..1)
 	# with (0..x) where x is equal to your number of fit parameters
 	# minus 1
-        my ($m,$b) = map { $par->slice("($_)") } (0..1);
+        my ($m,$c) = map { $par->slice("($_)") } (0..1);
 
 	# Write function with dependent variable $ym,
 	# independent variable $x, and fit parameters as specified above.
 	# Use the .= (dot equals) assignment operator to express the equality
 	# (not just a plain equals)
-        $ym .= $m * $x + $b;
+        $ym .= $m * $x + $c;
 
 	# Edit only the (0..1) part to (0..x) as above
         my (@dy) = map {$dyda -> slice(",($_)") } (0..1);
@@ -78,7 +78,7 @@ sub linefit {
         $dy[0] .= $x;
 
 	# Partial derivative of the function with respect to next
-        # fit parameter ($b in this case)
+        # fit parameter ($c in this case)
 	$dy[1] .= 1;
 
 	# Add $dy[ ] .= () lines as necessary to supply
